# FundingV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV30**](CreatedDateV30.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV30**](LastModifiedDateV30.md) |  | [optional] 
**source** | [**SourceV30**](SourceV30.md) |  | [optional] 
**put_code** | **int** |  | [optional] 
**path** | **str** |  | [optional] 
**type** | **str** |  | 
**organization_defined_type** | [**OrganizationDefinedFundingSubTypeV30**](OrganizationDefinedFundingSubTypeV30.md) |  | [optional] 
**title** | [**FundingTitleV30**](FundingTitleV30.md) |  | 
**short_description** | **str** |  | [optional] 
**amount** | [**AmountV30**](AmountV30.md) |  | [optional] 
**url** | [**UrlV30**](UrlV30.md) |  | [optional] 
**start_date** | [**FuzzyDateV30**](FuzzyDateV30.md) |  | [optional] 
**end_date** | [**FuzzyDateV30**](FuzzyDateV30.md) |  | [optional] 
**external_ids** | [**ExternalIDsV30**](ExternalIDsV30.md) |  | [optional] 
**contributors** | [**FundingContributorsV30**](FundingContributorsV30.md) |  | [optional] 
**organization** | [**OrganizationV30**](OrganizationV30.md) |  | 
**visibility** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

